@@ -6,3 +6,5 @@ if [ ! -r usr/X11R6/lib/X11/config/host.def ]; then
 fi
 ( cd usr/include ; rm -rf GL )
 ( cd usr/include ; ln -sf /usr/X11R6/include/GL GL )
+( cd usr/include ; rm -rf freetype )
+( cd usr/include ; ln -sf freetype2/freetype freetype )
